import React from "react";
import PropTypes from "prop-types";
import UmamiAnalytics from "./umami/UmamiAnalytics";
import MatomoAnalytics from "./matomo/MatomoAnalytics";

const AnalyticsSwitch = ({ disabled, umami, matomo }) => {
  if (disabled) return "";

  return (
    <>
      {umami && umami.enabled && <UmamiAnalytics {...umami} />}
      {matomo && matomo.enabled && <MatomoAnalytics {...matomo} />}
    </>
  );
};

AnalyticsSwitch.defaultProps = {
  disabled: false
};

AnalyticsSwitch.propTypes = {
  disabled: PropTypes.bool,
  umami: PropTypes.shape({
    enabled: PropTypes.bool.isRequired,
    source: PropTypes.string.isRequired,
    websiteId: PropTypes.string.isRequired
  }),
  matomo: PropTypes.shape({
    enabled: PropTypes.bool.isRequired,
    source: PropTypes.string.isRequired,
    websiteId: PropTypes.string.isRequired
  })
};

export default AnalyticsSwitch;
